package com.fdage.dao.base;

import com.fdage.pojo.TbCollectionTime;

public interface TbCollectionTimeMapper {
    int deleteByPrimaryKey(Long id);

    int insert(TbCollectionTime record);

    int insertSelective(TbCollectionTime record);

    TbCollectionTime selectByPrimaryKey(Long id);

    int updateByPrimaryKeySelective(TbCollectionTime record);

    int updateByPrimaryKey(TbCollectionTime record);
}